@@ -5,3 +5,5 @@ from . import logging
 from . import obfuscator
 from . import random
 from . import socket
+from . import change_ip
+from . import check_ip
